@@ -3,7 +3,7 @@ package App::YoutubeDlIfNotYet;
 our $AUTHORITY = 'cpan:PERLANCAR'; # AUTHORITY
 our $DATE = '2020-04-05'; # DATE
 our $DIST = 'App-YoutubeDlIfNotYet'; # DIST
-our $VERSION = '0.002'; # VERSION
+our $VERSION = '0.003'; # VERSION
 
 use 5.010001;
 use strict;
@@ -37,7 +37,7 @@ sub _search_id_in_log_file {
 
 $SPEC{youtube_dl_if_not_yet} = {
     v => 1.1,
-    summary => 'Download videos using youtube-dl only if videos have not been donwnloaded yet',
+    summary => '(DEPRECATED) Download videos using youtube-dl only if videos have not been donwnloaded yet',
     description => <<'_',
 
 This is a wrapper for **youtube-dl**; it tries to extract downloaded video ID's
@@ -114,7 +114,7 @@ sub youtube_dl_if_not_yet {
 }
 
 1;
-# ABSTRACT: Download videos using youtube-dl only if videos have not been donwnloaded yet
+# ABSTRACT: (DEPRECATED) Download videos using youtube-dl only if videos have not been donwnloaded yet
 
 __END__
 
@@ -124,11 +124,15 @@ __END__
 
 =head1 NAME
 
-App::YoutubeDlIfNotYet - Download videos using youtube-dl only if videos have not been donwnloaded yet
+App::YoutubeDlIfNotYet - (DEPRECATED) Download videos using youtube-dl only if videos have not been donwnloaded yet
 
 =head1 VERSION
 
-This document describes version 0.002 of App::YoutubeDlIfNotYet (from Perl distribution App-YoutubeDlIfNotYet), released on 2020-04-05.
+This document describes version 0.003 of App::YoutubeDlIfNotYet (from Perl distribution App-YoutubeDlIfNotYet), released on 2020-04-05.
+
+=head1 DEPRECATION NOTICE
+
+Superseded by L<youtube-dl-if> (from L<App::YoutubeDlIf>).
 
 =head1 DESCRIPTION
 
@@ -141,7 +145,7 @@ Usage:
 
  youtube_dl_if_not_yet(%args) -> [status, msg, payload, meta]
 
-Download videos using youtube-dl only if videos have not been donwnloaded yet.
+(DEPRECATED) Download videos using youtube-dl only if videos have not been donwnloaded yet.
 
 This is a wrapper for B<youtube-dl>; it tries to extract downloaded video ID's
 from filenames or URL's or video ID's listed in a text file, e.g.:
